@@ -136,10 +136,11 @@ class BibItem(dict):
       'author'     : (r'\authors{',r'}. '),
       'title'      : (r' \textbf{',r'} '),
       'journal'    : (r' \emph{',r'} '),
+      'booktitle'  : (r' \emph{',r'}, '),
       'volume'     : (r' \textbf{',r'}'),
-      'year'       : (r', ',r'.'),
-      'firstpage'  : (r', ',r''),
-      'lastpage'   : (r'-',r''),
+      'year'       : (r' ',r'.'),
+      'firstpage'  : (r' ',r''),
+      'lastpage'   : (r'-',r','),
       'number'     : (':',''),
       'school'     : ('',''),
       'url'        : (r' \url{',r'}'),
@@ -332,13 +333,28 @@ class BibItem(dict):
         autores= ' and '.join(self.get_authorsList(format=1,who=f))
         wrap.initial_indent=initial_indent
         s+= wrap.fill(f + ' = {' + autores +'},') + '\n'
+
+    # put braces around upper case in titles
+    textualfields = helper.textualfields[:]
+    braces_field = ['title']
+    for kk in braces_field: 
+      textualfields.remove(kk)
+      if self.has_key(kk): 
+        tit= helper.removebraces(self[kk])
+        f = tit[0]
+        for  c in tit[1:]:
+          if c.isupper():
+            f = f + '{' + c + '}'
+          else: f = f + c
+        s += wrap.fill('%s = {%s},' % (kk , f))+'\n'
+
     # Some fields that are copied literally
-    for kk in helper.textualfields:
+    for kk in textualfields:
       if self.has_key(kk) and not kk.startswith('_'):
-				if kk in helper.nowrapfields:  # Not wrap
-					s+= '%s%s = {%s}, \n' % (initial_indent,kk , self[kk])
-				else:
-					s+= wrap.fill('%s = {%s},' % (kk , self[kk]))+'\n'
+        if kk in helper.nowrapfields:  # Not wrap
+          s+= '%s%s = {%s}, \n' % (initial_indent,kk , self[kk])
+        else:
+          s+= wrap.fill('%s = {%s},' % (kk , self[kk]))+'\n'
     # Pages field
     p= self.get_field('pages')
     if p != '':
@@ -396,7 +412,7 @@ class BibItem(dict):
     st.update(style)
     tipo= self.get('_type','article')
     title= helper.handle_math(self.get_field('title',''))
-    title= bibparse.helper.capitalizestring(title)
+    title= helper.removebraces(title)
     if 'mastersthesis' == tipo:  title= 'Master Thesis. ' + title
     elif 'phdthesis' == tipo:    title= 'Phd Thesis. ' + title
 
@@ -450,8 +466,8 @@ class BibItem(dict):
     for field in textfields:
       if self.get_field(field,'') != '' and st.get(field) != None:
         s+= self.get_field(field,'').strip().join(st[field])
-
-    return s.encode('latex')
+    # return s.encode('latex')
+    return s
 
   def display(self, fpp=sys.stdout):
     if type(fpp)==type(''):
