@@ -92,7 +92,7 @@ def get_fields(strng, strict=False):
 # Creates a (hopefully) unique key code
 def create_entrycode(b={}):
   """
-  Creates a 'hopefully unique' entry key from a 
+  Creates a 'hopefully unique' entry key from a bibtex item
   """
   len_aut=7  # Length of the author surname used
   try:
@@ -111,7 +111,7 @@ def create_entrycode(b={}):
 
   if b['_type'] == 'mastersthesis':   bibid+= 'MT'
   elif b['_type'] == 'phdthesis':    bibid+= 'PHD'
-  elif b['_type'] in ['book','incollection','proceedings','conference']:
+  elif b['_type'] in ['book','incollection','proceedings','conference','misc','techreport']:
     if b.has_key('booktitle'):
       bibid+= helper.create_initials(b['booktitle'])
     elif b.has_key('series'):
@@ -166,8 +166,6 @@ def parsedata(data):
 
     if m.group(0)[-1]=='(':
       d= helper.match_pair(ss,pair=('[(]','[)]'),start=m.end()-1)
-#       d= helper.match_pair(ss,pair=('(',')'),start=m.end()-1)
-#       print m.group(0)
     else:
       d= helper.match_pair(ss,start=m.end()-1)
 
