@@ -7,12 +7,12 @@ import sys
 allfields = ('_type', 'address', 'author', 'booktitle', 'chapter', 'edition','_code',
 'editor', 'howpublished', 'institution', 'journal', 'month', 'number', 'organization',
 'pages', 'publisher', 'school','series', 'title', 'volume','year', 'note', 'code',
-'url', 'crossref', 'annote', 'abstract', 'doi','journal_abbrev','date-added','date-modified')
+'url', 'crossref', 'annote', 'abstract', 'doi','journal_abbrev','date-added','date-modified', 'file')
 
 bibtexfields = ('author', 'title', 'journal', 'year', 'volume','number', 'pages', 'month',
 'booktitle', 'chapter','address', 'edition', 'abstract', 'doi',  'url', 'editor',
 'howpublished','school', 'institution', 'organization', 'publisher', 'series',
-'note', 'crossref', 'annote')
+'note', 'crossref', 'annote','file')
 
 # Fields that MUST be present
 minimalfields = ('_type','author')
@@ -20,7 +20,7 @@ minimalfields = ('_type','author')
 # Fields that are output literally in bibtex form
 textualfields = ['title', 'journal', 'year', 'volume','number', 'month', 'booktitle', 'chapter',
 'address', 'edition', 'howpublished','school', 'institution', 'organization', 'publisher', 'series',
-'note', 'crossref', 'issn','isbn', 'keywords' ,'annote', '_code', 'doi',  'url',  'abstract']
+'note', 'crossref', 'issn','isbn', 'keywords' ,'annote', '_code', 'doi',  'url',  'abstract','file']
 
 # Fields that should not be wrapped (must go complete in the same line)
 nowrapfields= ['url','doi','isbn','issn','crossref']
